# tanjun.context

Standard implementations of Tanjun's context classes.

::: tanjun.context.autocomplete
    rendering:
        show_root_heading: true

::: tanjun.context.menu
    rendering:
        show_root_heading: true

::: tanjun.context.message
    rendering:
        show_root_heading: true

::: tanjun.context.slash
    rendering:
        show_root_heading: true
